/**
 * Organization plugin API types for @agentuity/auth.
 *
 * Server-side API methods for organization management provided by BetterAuth's
 * organization plugin. Includes multi-tenancy support, member management,
 * invitations, and access control.
 *
 * @see https://better-auth.com/docs/plugins/organization
 * @module agentuity/plugins/organization
 */
export {};
//# sourceMappingURL=organization.js.map