/**
 * Plugin type exports for @agentuity/auth.
 *
 * This module re-exports all plugin-specific types and interfaces for
 * convenient access. Each plugin has its own file for easier maintenance.
 *
 * @module agentuity/plugins
 */
export { DEFAULT_API_KEY_OPTIONS } from "./api-key.js";
//# sourceMappingURL=index.js.map