/**
 * Core authentication types for Agentuity Auth.
 *
 * These types are now defined in @agentuity/core for better dependency management.
 * This module re-exports them for backwards compatibility.
 *
 * @module types
 */
export type { AgentuityAuth } from '@agentuity/core';
//# sourceMappingURL=types.d.ts.map