/**
 * JWT plugin types for @agentuity/auth.
 *
 * Server-side API methods for JWT token management provided by BetterAuth's
 * JWT plugin. Enables token-based authentication.
 *
 * @see https://better-auth.com/docs/plugins/jwt
 * @module agentuity/plugins/jwt
 */
export {};
//# sourceMappingURL=jwt.js.map